@@ -4,13 +4,13 @@
 /// "Use Terms").   Any redistribution of this code must retain the above 
 /// copyright and this notice and otherwise comply with the Use Terms.
 /**
- * @path ch15/15.2/15.2.3/15.2.3.8/15.2.3.8-0-2.js
- * @description Object.seal must exist as a function taking 1 parameter
+ * @path ch15/15.2/15.2.3/15.2.3.10/15.2.3.10-0-2.js
+ * @description Object.preventExtensions must exist as a function taking 1 parameter
  */
 
 
 function testcase() {
-  if (Object.seal.length === 1) {
+  if (Object.preventExtensions.length === 1) {
     return true;
   }
  }
